@@ -1,8 +1,8 @@
 pub mod admissionregistration;
 
-pub mod apps;
+pub mod apiserverinternal;
 
-pub mod auditregistration;
+pub mod apps;
 
 pub mod authentication;
 
@@ -22,8 +22,6 @@ pub mod discovery;
 
 pub mod events;
 
-pub mod extensions;
-
 pub mod flowcontrol;
 
 pub mod networking;
@@ -34,8 +32,8 @@ pub mod policy;
 
 pub mod rbac;
 
+pub mod resource;
+
 pub mod scheduling;
 
-pub mod settings;
-
 pub mod storage;
